<?php
ob_start(); // Start output buffering at the very top

if (session_status() == PHP_SESSION_NONE) {
    session_start();
}

include 'config/db_config.php';

// Function to generate a user ID
function generateUserID($id) {
    $randomNumber = rand(1000, 9999); // Generate a random number between 1000 and 9999
    return "bsq-$randomNumber-$id";
}

// User registration logic
if ($_SERVER["REQUEST_METHOD"] === "POST" && isset($_POST['register'])) {
    if (isset($_POST["firstname"], $_POST["lastname"], $_POST["email"], $_POST["phone"], $_POST["password"], $_POST["lga"], $_POST["department"], $_POST["designation"], $_POST["role"])) {
        $firstname = $_POST["firstname"];
        $lastname = $_POST["lastname"];
        $email = $_POST["email"];
        $phone = $_POST["phone"];
        $password = $_POST["password"];
        $lga = $_POST["lga"];
        $department = $_POST["department"];
        $designation = $_POST["designation"];
        $role = $_POST["role"];

        // Check if the email already exists in the database
        $check_email_query = "SELECT * FROM user_role WHERE email = ?";
        $check_stmt = mysqli_prepare($conn, $check_email_query);
        
        if ($check_stmt) {
            mysqli_stmt_bind_param($check_stmt, "s", $email);
            mysqli_stmt_execute($check_stmt);
            mysqli_stmt_store_result($check_stmt);
            
            if (mysqli_stmt_num_rows($check_stmt) > 0) {
                // Email already exists, handle accordingly
                $registration = "Email already exists. Please use a different email address.";
            } else {
                // Email doesn't exist, proceed with registration

                // Hash the password
                $hashedPassword = password_hash($password, PASSWORD_BCRYPT);

                // Use prepared statements to prevent SQL injection
                $sql = "INSERT INTO user_role (firstname, lastname, email, phone, password, lga, department, designation, role) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?)";

                $stmt = mysqli_prepare($conn, $sql);

                if ($stmt) {
                    mysqli_stmt_bind_param($stmt, "sssssssss", $firstname, $lastname, $email, $phone, $hashedPassword, $lga, $department, $designation, $role);
                    mysqli_stmt_execute($stmt);

                    if (mysqli_stmt_affected_rows($stmt) > 0) {
                        // Get the last inserted ID
                        $last_id = mysqli_insert_id($conn);
                        // Generate the user ID
                        $user_id = generateUserID($last_id);
                        
                        // Update the record with the generated user ID
                        $update_sql = "UPDATE user_role SET user_id = ? WHERE id = ?";
                        $update_stmt = mysqli_prepare($conn, $update_sql);
                        if ($update_stmt) {
                            mysqli_stmt_bind_param($update_stmt, "si", $user_id, $last_id);
                            mysqli_stmt_execute($update_stmt);
                            mysqli_stmt_close($update_stmt);
                        }

                        // Registration successful
                        $registration = "Registration successful.";
                    } else {
                        // Registration failed
                        $registration = "Registration failed.";
                    }

                    mysqli_stmt_close($stmt);
                } else {
                    // Error in database query
                    $registration = "Error in database query.";
                }
            }

            mysqli_stmt_close($check_stmt);
        } else {
            // Error in email check query
            $registration = "Error in email check query.";
        }
    }
}

// Update User Logic
if ($_SERVER["REQUEST_METHOD"] === "POST" && isset($_POST['update'])) {
    if (isset($_POST["id"], $_POST["firstname"], $_POST["lastname"], $_POST["email"], $_POST["phone"], $_POST["lga"], $_POST["department"], $_POST["designation"], $_POST["role"])) {
        $id = $_POST["id"];
        $firstname = $_POST["firstname"];
        $lastname = $_POST["lastname"];
        $email = $_POST["email"];
        $phone = $_POST["phone"];
        $lga = $_POST["lga"];
        $department = $_POST["department"];
        $designation = $_POST["designation"];
        $role = $_POST["role"];

        // Use prepared statements to prevent SQL injection
        $sql = "UPDATE user_role SET firstname = ?, lastname = ?, email = ?, phone = ?, lga = ?, department = ?, designation = ?, role = ? WHERE id = ?";

        $stmt = mysqli_prepare($conn, $sql);

        if ($stmt) {
            mysqli_stmt_bind_param($stmt, "ssssssssi", $firstname, $lastname, $email, $phone, $lga, $department, $designation, $role, $id);
            mysqli_stmt_execute($stmt);

            if (mysqli_stmt_affected_rows($stmt) > 0) {
                // Update successful
                $_SESSION['update_message'] = "User updated successfully.";
            } else {
                // Update failed
                $_SESSION['update_message'] = "No changes were made to the user record.";
            }

            mysqli_stmt_close($stmt);
        } else {
            // Error in database query
            $_SESSION['update_message'] = "Error updating user record.";
        }
    }
}

// Delete Logic
if ($_SERVER["REQUEST_METHOD"] === "POST" && isset($_POST['delete'])) {
    $id = $_POST['id'];

    // Prepare the statement only if the connection is open
    if ($conn) {
        $sql = "DELETE FROM user_role WHERE id = ?";
        $stmt = $conn->prepare($sql);
    
        if ($stmt) {
            $stmt->bind_param("i", $id);
            $stmt->execute();
            if ($stmt->affected_rows > 0) {
                // Deletion successful
                $_SESSION['delete_message'] = "User deleted successfully";
            } else {
                // Deletion failed
                $_SESSION['delete_message'] = "Error deleting user record.";
            }
            $stmt->close();
        }
    }
}

// Close the database connection after all operations
if ($conn) {
    mysqli_close($conn);
}
if (isset($_SESSION['update_message']) && $_SESSION['update_message'] !== "") {
    header("Location:user.php");
    ob_end_flush(); // Flush the output buffer and send it to the browser
    exit();
}
 
// Handle redirections and buffer flushing
if (isset($_SESSION['delete_message']) && $_SESSION['delete_message'] !== "") {
    header("Location:user.php");
    ob_end_flush(); // Flush the output buffer and send it to the browser
    exit();
}

ob_end_flush(); // Flush the output buffer and send it to the browser (general case)
?>
