<?php
error_reporting(E_ALL);
ini_set('display_errors', 1);

// Start a new session or resume the existing session
session_start();

// Include the database configuration file
include 'config/db_config.php';

if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['email'], $_POST['password'])) {
    // Get user inputs (validate and sanitize them)
    $email = mysqli_real_escape_string($conn, $_POST['email']);
    $password = mysqli_real_escape_string($conn, $_POST['password']);

    // SQL query with prepared statement
    $sql = "SELECT id, user_id, email, password, firstname, lastname, designation, lga, role FROM user_role WHERE email=?";

    // Prepare the SQL statement
    $stmt = mysqli_prepare($conn, $sql);
    if (!$stmt) {
        die("Prepare failed: " . mysqli_error($conn));
    }

    // Bind parameters to the prepared statement
    mysqli_stmt_bind_param($stmt, "s", $email);

    // Execute the prepared statement
    mysqli_stmt_execute($stmt);

    // Store the result so we can check the number of rows
    mysqli_stmt_store_result($stmt);
    
    if (mysqli_stmt_num_rows($stmt) == 1) {
        // Bind the result variables
        mysqli_stmt_bind_result($stmt, $id, $user_id, $db_email, $db_password, $firstname, $lastname, $designation, $lga, $role);
        // Fetch values
        mysqli_stmt_fetch($stmt);

        // Verify the password
        if (password_verify($password, $db_password)) {
            // Password is correct
            // Store user information in session variables
            $_SESSION["user_id"] = $user_id;
            $_SESSION["firstname"] = $firstname;
            $_SESSION["lastname"] = $lastname;
            $_SESSION["designation"] = $designation;
            $_SESSION["lga"] = $lga;
            $_SESSION["role"] = $role;
            $_SESSION["logged_in"] = true;

            // Redirect the user based on their role
            switch ($role) {
                case "admin":
                    header("location: sprc.php");
                    exit();
                case "state":
                        header("location: observation.php");
                        exit();
                case "lga":
                    header("location: mentoring.php");
                    exit();
                
                default:
                    echo "Unknown role!";
            }
        } else {
            // If password is incorrect, set an error message
            $wrong = "Wrong Username or Password";
        }
        // Close the statement
        mysqli_stmt_close($stmt);
    } else {
        // If no matching row found, set an error message
        $wrong = "Wrong Username or Password";
    }

    // Close the database connection
    mysqli_close($conn);
}


?>
