<?php
error_reporting(E_ALL);
ini_set('display_errors', 1);

session_start();

// Check if the user is logged in and has the 'admin' role
if (!isset($_SESSION["logged_in"]) || $_SESSION["role"] !== "admin") {
    header("Location: index.php");
    exit();
}

// Check for messages
$upload_message = isset($_SESSION['upload_message']) ? $_SESSION['upload_message'] : '';
unset($_SESSION['upload_message']); // Clear upload message

include 'config/db_config.php'; // Include your database connection configuration

// Initialize message variables
$success_message = '';
$error_message = '';

// Handle form submission to add or update page
if ($_SERVER['REQUEST_METHOD'] == 'POST' && !isset($_POST['delete'])) {
    if (isset($_POST['title']) && isset($_POST['link']) && isset($_POST['roles'])) {
        $title = $_POST['title'];
        $link = $_POST['link'];
        $role_ids = $_POST['roles'];

        if (isset($_POST['id']) && !empty($_POST['id'])) {
            // Update existing page
            $id = $_POST['id'];

            $stmt = $conn->prepare("UPDATE pages SET title = ?, link = ? WHERE id = ?");
            $stmt->bind_param("ssi", $title, $link, $id);
            if ($stmt->execute()) {
                // Delete existing roles
                $delete_role_stmt = $conn->prepare("DELETE FROM page_roles WHERE page_id = ?");
                $delete_role_stmt->bind_param("i", $id);
                $delete_role_stmt->execute();
                $delete_role_stmt->close();

                // Assign new roles to the updated page
                foreach ($role_ids as $role_id) {
                    $role_stmt = $conn->prepare("INSERT INTO page_roles (page_id, role_id) VALUES (?, ?)");
                    $role_stmt->bind_param("ii", $id, $role_id);
                    $role_stmt->execute();
                    $role_stmt->close();
                }

                $success_message = 'Page updated successfully!';
            } else {
                $error_message = 'Failed to update the page!';
            }
            $stmt->close();
        } else {
            // Insert new page
            $check_stmt = $conn->prepare("SELECT COUNT(*) FROM pages WHERE title = ?");
            $check_stmt->bind_param("s", $title);
            $check_stmt->execute();
            $check_stmt->bind_result($count);
            $check_stmt->fetch();
            $check_stmt->close();

            if ($count > 0) {
                $error_message = 'Page title already exists!';
            } else {
                $stmt = $conn->prepare("INSERT INTO pages (title, link) VALUES (?, ?)");
                $stmt->bind_param("ss", $title, $link);
                if ($stmt->execute()) {
                    $page_id = $stmt->insert_id;
                    foreach ($role_ids as $role_id) {
                        $role_stmt = $conn->prepare("INSERT INTO page_roles (page_id, role_id) VALUES (?, ?)");
                        $role_stmt->bind_param("ii", $page_id, $role_id);
                        $role_stmt->execute();
                        $role_stmt->close();
                    }
                    $success_message = 'Page added successfully!';
                } else {
                    $error_message = 'Failed to add the page!';
                }
                $stmt->close();
            }
        }
    } else {
        $error_message = 'Please fill in all required fields.';
    }
}

// Handle delete request
if (isset($_POST['delete']) && $_POST['delete'] == 'true') {
    $id = $_POST['id'];

    // Delete associated roles first
    $delete_role_stmt = $conn->prepare("DELETE FROM page_roles WHERE page_id = ?");
    $delete_role_stmt->bind_param("i", $id);
    if ($delete_role_stmt->execute()) {
        $stmt = $conn->prepare("DELETE FROM pages WHERE id = ?");
        $stmt->bind_param("i", $id);
        if ($stmt->execute()) {
            $success_message = 'Page deleted successfully!';
        } else {
            $error_message = 'Failed to delete the page!';
        }
        $stmt->close();
    } else {
        $error_message = 'Failed to delete associated roles!';
    }
    $delete_role_stmt->close();
}

// Fetch pages from the database
$pages_sql = "SELECT * FROM pages";
$pages_result = mysqli_query($conn, $pages_sql);

// Fetch roles from the database for the form
$roles_sql = "SELECT * FROM roles";
$roles_result = mysqli_query($conn, $roles_sql);

// Function to fetch roles for a specific page
function fetch_page_roles($conn, $page_id) {
    $roles_sql = "SELECT role_id FROM page_roles WHERE page_id = ?";
    $stmt = $conn->prepare($roles_sql);
    $stmt->bind_param("i", $page_id);
    $stmt->execute();
    $result = $stmt->get_result();
    $roles = [];
    while ($row = $result->fetch_assoc()) {
        $roles[] = $row['role_id'];
    }
    $stmt->close();
    return $roles;
}
?>

<!doctype html>
<html lang="en">
<head>
    <meta charset="utf-8" />
    <title>SKUMONITOR - Page Management</title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta content="Sokoto State Unified School Monitoring System" name="description" />
    <meta content="Themesbrand" name="author" />
    <link rel="shortcut icon" href="assets/images/favicon.ico">
    <link href="assets/libs/magnific-popup/magnific-popup.css" rel="stylesheet" type="text/css" />
    <link href="assets/css/bootstrap.css" id="bootstrap-style" rel="stylesheet" type="text/css" />
    <link href="assets/css/icons.css" rel="stylesheet" type="text/css" />
    <link href="assets/css/app.css" id="app-style" rel="stylesheet" type="text/css" />
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
</head>

<body data-sidebar="dark" data-topbar="dark">
    <div id="layout-wrapper">
        <?php include 'header.php'; ?>

        <div class="vertical-menu">
            <?php include 'nav.php'; ?>
        </div>

        <div class="main-content">
            <div class="page-content">
                <div class="container-fluid">
                    <div class="row">
                        <div class="col-12">
                            <div class="page-title-box d-flex align-items-center justify-content-between">
                                <h4 class="mb-0">Page Management</h4>
                                <div class="page-title-right">
                                    <ol class="breadcrumb m-0">
                                        <li class="breadcrumb-item"><a href="javascript: void(0);">Administration</a></li>
                                        <li class="breadcrumb-item active">Page Management</li>
                                    </ol>
                                </div>
                            </div>
                        </div>
                    </div>

                    <?php
                    if ($success_message) {
                        echo '<div class="alert alert-success">' . htmlspecialchars($success_message) . '</div>';
                    }
                    if ($error_message) {
                        echo '<div class="alert alert-danger">' . htmlspecialchars($error_message) . '</div>';
                    }
                   
                    if (isset($upload_message) && !empty($upload_message)) {
                        echo '<div class="alert alert-success">' . htmlspecialchars($upload_message) . '</div>';
                            unset($_SESSION['upload_message']);
                                            }
                    ?>

                    <div class="row">
                        <div class="col-lg-12">
                            <div class="card">
                                <div class="card-body">
                                    <div class="row mb-2">
                                        <div class="col-md-8"></div>
                                        
                                        <div class="col-md-4">
                                            <div class="form-inline float-md-end mb-3 mx-1">
                                                <div class="card-header-right">
                                                    <a class="popup-form btn btn-block btn-success mb-4 " data-toggle="modal" href="#addPageForm"><i class="mdi mdi-plus me-2"></i> Add New Page</a>
                                                </div>
                                            </div>
                                            <div class="form-inline float-md-end mb-3 mx-1">
                                                <a class="popup-form btn btn-primary" href="#upload-form"><i class="mdi mdi-cloud-upload me-2"></i> Upload New File</a>
                                            </div>
                                        </div>
                                        
                                        <div class="card mfp-hide mfp-popup-form mx-auto" id="addPageForm">
                                            <div class="card-body">
                                                <h4 class="mb-4">Add New Page</h4>   
                                                <form class="needs-validation" novalidate action="" method="POST">
                                                    <input type="hidden" name="id" id="edit-page-id">
                                                    <div class="mb-3">
                                                        <label for="title">Page Title</label>
                                                        <input type="text" class="form-control" id="title" name="title" required>
                                                    </div>
                                                    <div class="mb-3">
                                                        <label for="link">Page Link</label>
                                                        <input type="text" class="form-control" id="link" name="link" required>
                                                    </div>
                                                    <div class="mb-3">
                                                        <label for="roles">Assign to Roles</label>
                                                        <?php while ($row = $roles_result->fetch_assoc()) : ?>
                                                            <div>
                                                                <input type="checkbox" id="role_<?php echo $row['id']; ?>" name="roles[]" value="<?php echo $row['id']; ?>">
                                                                <label for="role_<?php echo $row['id']; ?>"><?php echo $row['name']; ?></label>
                                                            </div>
                                                        <?php endwhile; ?>
                                                    </div>
                                                    <button class="btn btn-success w-lg me-1" type="submit">Add Page</button>
                                                    <button type="reset" class="btn btn-secondary waves-effect">Reset</button>
                                                </form>
                                            </div>
                                        </div>
                                        <?php include 'config/upload_config.php'; ?>
                                        <div class="card mfp-hide mfp-popup-form mx-auto" id="upload-form">
                                            <div class="card-body">
                                                <h4 class="mb-4">Upload New File</h4>   
                                                <form class="needs-validation" novalidate action="" id="uploadForm" method="POST" enctype="multipart/form-data">
                                                    <div class="mb-3">
                                                        <label for="fileUpload">Choose file</label>
                                                        <input type="file" class="form-control" id="fileUpload" name="fileUpload" required>
                                                        <div class="invalid-feedback">
                                                            Please choose a file to upload.
                                                        </div>
                                                    </div>
                                                    <div class="mb-3 form-check">
                                                        <input type="checkbox" class="form-check-input" id="replaceFile" name="replaceFile">
                                                        <label class="form-check-label" for="replaceFile">Replace if file exists</label>
                                                    </div>
                                                    <button class="btn btn-success w-lg me-1" type="submit">Upload File</button>
                                                    <button type="reset" class="btn btn-secondary waves-effect">Reset</button>
                                                </form>
                                            </div>
                                        </div>
                                    </div>

                                    <div class="table-responsive mb-4">
                                        <div class="card-body table-border-style">
                                            <div class="table-responsive">
                                                <?php
                                                if (mysqli_num_rows($pages_result) > 0) {
                                                    echo "<table class='table table-centered table-nowrap mb-0'>
                                                    <thead>
                                                    <tr>
                                                        <th scope='col' style='width: 50px;'>
                                                            <div class='form-check font-size-16'>
                                                                <input type='checkbox' class='form-check-input' id='contacusercheck'>
                                                                <label class='form-check-label' for='contacusercheck'></label>
                                                            </div>
                                                        </th>";
                                                    echo "<th scope='col'>Page Title</th>
                                                        <th scope='col'>Page Link</th>
                                                        <th scope='col'>Roles</th>
                                                        <th scope='col' style='width: 200px;'>Action</th>
                                                    </tr>
                                                    </thead>
                                                    <tbody>";

                                                    while ($row = mysqli_fetch_assoc($pages_result)) {
                                                        $role_sql = "SELECT roles.name FROM page_roles JOIN roles ON page_roles.role_id = roles.id WHERE page_roles.page_id = " . $row['id'];
                                                        $role_result = mysqli_query($conn, $role_sql);
                                                        $roles = [];
                                                        while ($role_row = mysqli_fetch_assoc($role_result)) {
                                                            $roles[] = $role_row['name'];
                                                        }
                                                        $roles_str = implode(', ', $roles);

                                                        echo "<tr>";
                                                        echo "<th scope='row'>
                                                            <div class='form-check font-size-16'>
                                                                <input type='checkbox' class='form-check-input' id='contacusercheck2'>
                                                                <label class='form-check-label' for='contacusercheck2'></label>
                                                            </div>
                                                        </th>";
                                                        echo "<td>" . htmlspecialchars($row['title']) . "</td>";
                                                        echo "<td>" . htmlspecialchars($row['link']) . "</td>";
                                                        echo "<td>" . htmlspecialchars($roles_str) . "</td>";
                                                        echo "<td>
                                                            <ul class='list-inline mb-0'>
                                                                <li class='list-inline-item'>
                                                                    <a href='#updatepage-form' class='editbtn popup-form px-2 text-primary' data-id='" . $row['id'] . "' data-title='" . htmlspecialchars($row['title']) . "' data-link='" . htmlspecialchars($row['link']) . "'>
                                                                        <i class='uil uil-pen font-size-18'></i>
                                                                    </a>
                                                                </li>
                                                                <li class='list-inline-item'>
                                                                    <a href='#deletepage-form' class='deletebtn popup-form px-2 text-danger' data-id='" . $row['id'] . "'>
                                                                        <i class='uil uil-trash-alt font-size-18'></i>
                                                                    </a>
                                                                </li>
                                                            </ul>
                                                        </td>";
                                                        echo "</tr>";
                                                    }
                                                    echo "</tbody></table>";
                                                } else {
                                                    echo "No pages found in the database.";
                                                }
                                                ?>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>

                            <!-- Delete confirmation popup -->
                            <div class="card mfp-hide popdelete mfp-popup-form mx-auto" id="deletepage-form">
                                <div class="card-body">
                                    <h4 class="mb-4">Confirm Page Deletion</h4>
                                    <form class="needs-validation" novalidate action="" method="POST">
                                        <input type="hidden" name="delete" value="true">
                                        <input type="hidden" name="id" id="delete-page-id">
                                        <p>Are you sure you want to delete this page?</p>
                                        <button class="btn btn-danger" type="submit">Yes, Delete it</button>
                                    </form>
                                </div>
                            </div>

                            <!-- Update page popup -->
                            <div class="card mfp-hide mfp-popup-form mx-auto" id="updatepage-form">
                                <div class="card-body">
                                    <h4 class="mb-4">Update Page Details</h4>   
                                    <form class="needs-validation" novalidate action="" method="POST">
                                        <input type="hidden" name="id" id="edit-page-id">
                                        <div class="mb-3">
                                            <label for="title">Page Title</label>
                                            <input type="text" class="form-control" id="title" name="title" required>
                                        </div>
                                        <div class="mb-3">
                                            <label for="link">Page Link</label>
                                            <input type="text" class="form-control" id="link" name="link" required>
                                        </div>
                                        <div class="mb-3">
                                            <label for="roles">Assign to Roles</label>
                                            <?php
                                            // Fetch roles again for the update form
                                            $roles_result = mysqli_query($conn, $roles_sql);
                                            while ($role = mysqli_fetch_assoc($roles_result)) : ?>
                                                <div>
                                                    <input type="checkbox" id="role_<?php echo $role['id']; ?>" name="roles[]" value="<?php echo $role['id']; ?>">
                                                    <label for="role_<?php echo $role['id']; ?>"><?php echo $role['name']; ?></label>
                                                </div>
                                            <?php endwhile; ?>
                                        </div>
                                        <button class="btn btn-success w-lg me-1" type="submit">Update Page</button>
                                        <button type="reset" class="btn btn-secondary waves-effect">Reset</button>
                                    </form>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>

            <footer class="footer">
                <div class="container-fluid">
                    <div class="row">
                        <div class="col-sm-6"></div>
                        <div class="col-sm-6">
                            <div class="text-sm-end d-none d-sm-block">
                                <script>document.write(new Date().getFullYear())</script> © Sokoto State Unified School Monitoring System (SKUMONITOR). 
                            </div>
                        </div>
                    </div>
                </div>
            </footer>
        </div>

        <!-- JAVASCRIPT -->
        <script src="assets/libs/bootstrap/js/bootstrap.bundle.min.js"></script>
        <script src="assets/libs/metismenu/metisMenu.min.js"></script>
        <script src="assets/libs/simplebar/simplebar.min.js"></script>
        <script src="assets/libs/node-waves/waves.min.js"></script>
        <script src="assets/libs/waypoints/lib/jquery.waypoints.min.js"></script>
        <script src="assets/libs/jquery.counterup/jquery.counterup.min.js"></script>
        <script src="assets/libs/magnific-popup/jquery.magnific-popup.min.js"></script>
        <script src="assets/js/pages/lightbox.init.js"></script>
        <script src="assets/js/pages/form-validation.init.js"></script>
        <script src="assets/libs/@curiosityx/bootstrap-session-timeout/index.js"></script>
        <script src="assets/js/pages/session-timeout.init.js"></script>
        <script src="https://cdnjs.cloudflare.com/ajax/libs/parsley.js/2.9.2/parsley.min.js"></script>
        <script src="assets/js/app.js"></script>

        <script>
        document.addEventListener('DOMContentLoaded', function () {
            const deleteButtons = document.querySelectorAll('.deletebtn');
            deleteButtons.forEach(button => {
                button.addEventListener('click', function () {
                    const pageId = this.getAttribute('data-id');
                    document.getElementById('delete-page-id').value = pageId;
                });
            });

            const editButtons = document.querySelectorAll('.editbtn');
            editButtons.forEach(button => {
                button.addEventListener('click', function () {
                    const pageData = {
                        id: this.getAttribute('data-id'),
                        title: this.getAttribute('data-title'),
                        link: this.getAttribute('data-link')
                    };
                    document.getElementById('edit-page-id').value = pageData.id;
                    document.getElementById('title').value = pageData.title;
                    document.getElementById('link').value = pageData.link;

                    // Clear all role checkboxes
                    document.querySelectorAll('#roles input[type="checkbox"]').forEach(checkbox => {
                        checkbox.checked = false;
                    });

                    // Fetch roles for the specific page
                    fetchRolesForPage(pageData.id).then(roles => {
                        roles.forEach(roleId => {
                            const checkbox = document.querySelector(`#roles input[value="${roleId}"]`);
                            if (checkbox) checkbox.checked = true;
                        });
                    });

                    let updateInput = document.querySelector('#updatepage-form [name="update"]');
                    if (!updateInput) {
                        updateInput = document.createElement('input');
                        updateInput.type = 'hidden';
                        updateInput.name = 'update';
                        document.querySelector('#updatepage-form form').appendChild(updateInput);
                    }
                    updateInput.value = 'true';
                });
            });
        });

        function fetchRolesForPage(pageId) {
            return fetch(`config/fetch_roles.php?page_id=${pageId}`)
                .then(response => response.json())
                .then(data => data.roles);
        }
        </script>
    </div>
</body>
</html>
