<?php
error_reporting(E_ALL);
ini_set('display_errors', 1);

if (session_status() == PHP_SESSION_NONE) {
    session_start();
}
// Check if the user is logged in and has the 'admin' role
if (!isset($_SESSION["logged_in"]) || $_SESSION["role"] !== "admin") {
    // Redirect to index.php if the user is not logged in or not an admin
    header("Location: index.php");
    exit();
}

// Check for delete message
$delete_message = isset($_SESSION['delete_message']) ? $_SESSION['delete_message'] : '';
unset($_SESSION['delete_message']); // Clear delete message

$update_message = isset($_SESSION['update_message']) ? $_SESSION['update_message'] : '';
unset($_SESSION['update_message']); // Clear update message

$registration = isset($_SESSION['registration']) ? $_SESSION['registration'] : '';
unset($_SESSION['registration']); // Clear registration message

include 'config/db_config.php'; // Database configuration
?>


<!doctype html>
<html lang="en">

    <head>

        <meta charset="utf-8" />
        <title>SKUMONITOR - User Management</title>
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <meta content="Sokoto State Unified School Monitoring System" name="description" />
        <meta content="Themesbrand" name="author" />
        <link rel="shortcut icon" href="assets/images/favicon.ico">

        <link href="assets/libs/magnific-popup/magnific-popup.css" rel="stylesheet" type="text/css" />

        <link href="assets/css/bootstrap.css" id="bootstrap-style" rel="stylesheet" type="text/css" />
        <link href="assets/css/icons.css" rel="stylesheet" type="text/css" />
        <link href="assets/css/app.css" id="app-style" rel="stylesheet" type="text/css" />

        <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    </head>

    <body data-sidebar="dark" data-topbar="dark">
        <div id="layout-wrapper">
            <?php include 'header.php'; ?>  
            <div class="vertical-menu">
                <?php include 'nav.php'; ?>  
            </div>
            
            <div class="main-content">
                <div class="page-content">
                    <div class="container-fluid">
                        <div class="row">
                            <div class="col-12">
                                <div class="page-title-box d-flex align-items-center justify-content-between">
                                    <h4 class="mb-0">User Management</h4>
                                    <div class="page-title-right">
                                        <ol class="breadcrumb m-0">
                                            <li class="breadcrumb-item"><a href="javascript: void(0);">Administration</a></li>
                                            <li class="breadcrumb-item active">User Management</li>
                                        </ol>
                                    </div>
                                </div>
                            </div>
                        </div>
                        
                        <?php include 'config/user_config.php'; ?>
                        
                        <div class="row">
                            <div class="col-lg-12">
                                <div class="card">
                                    <div class="card-body">
                                        <div class="row mb-2">
                                            <div class="col-md-10">
                                            <?php
                                                if (!empty($delete_message)) {
                                                    echo '<div class="alert alert-success">' . htmlspecialchars($delete_message) . '</div>';
                                                }
                                                if (!empty($update_message)) {
                                                    echo '<div class="alert alert-success">' . htmlspecialchars($update_message) . '</div>';
                                                }
                                                if (!empty($registration)) {
                                                    echo '<div class="alert alert-success">' . htmlspecialchars($registration) . '</div>';
                                                }
                                            ?>
                                            </div>
                
                                            <div class="col-md-2">
                                                <div class="form-inline float-md-end mb-3">
                                                    <a class="popup-form btn btn-success" href="#adduser-form"><i class="mdi mdi-plus me-2"></i> Add New User</a>
                                                </div>
                                            </div>
                                            
                                            <div class="card mfp-hide mfp-popup-form mx-auto" id="adduser-form">
                                                <div class="card-body">
                                                    <h4 class="mb-4">Add New User</h4>   
                                                    <form class="needs-validation" novalidate action="user.php" id="addUserForm" method="POST">
                                                        <input type="hidden" name="id" id="edit-user-id">
                                                        <div class="row">
                                                            <div class="col-md-6">
                                                                <div class="mb-3">
                                                                    <label class="form-label" for="validationCustom01">First name</label>
                                                                    <input type="text" class="form-control" name="firstname" id="validationCustom01" placeholder="First name" required>
                                                                    <div class="valid-feedback">
                                                                        Please enter your first name
                                                                    </div>
                                                                </div>
                                                            </div>
                                                            <div class="col-md-6">
                                                                <div class="mb-3">
                                                                    <label class="form-label" for="validationCustom02">Last name</label>
                                                                    <input type="text" class="form-control" name="lastname" id="validationCustom02" placeholder="Last name" required>
                                                                    <div class="valid-feedback">
                                                                        Please enter your last name
                                                                    </div>
                                                                </div>
                                                            </div>
                                                        </div>
                                                        <div class="row">
                                                            <div class="col-md-4">
                                                                <div class="mb-3">
                                                                    <label class="form-label" for="validationCustom03">Email</label>
                                                                    <input type="email" class="form-control" name="email" id="validationCustom03" parsley-type="email" placeholder="Email" required>
                                                                    <div class="invalid-feedback">
                                                                        Please provide a valid email.
                                                                    </div>
                                                                </div>
                                                            </div>
                                                            <div class="col-md-4">
                                                                <div class="mb-3">
                                                                    <label class="form-label" for="validationCustom04">Phone number</label>
                                                                    <input data-parsley-type="number" type="number" name="phone" class="form-control" id="validationCustom04" data-parsley-minlength="11" placeholder="Phone" required>
                                                                    <div class="invalid-feedback">
                                                                        Please provide a valid Phone number.
                                                                    </div>
                                                                </div>
                                                            </div>
                                                            <div class="col-md-4">
                                                                <div class="mb-3">
                                                                    <label class="form-label" for="validationCustom05">Password</label>
                                                                    <input type="password" class="form-control" name="password" id="validationCustom05" placeholder="Password" required>
                                                                    <div class="invalid-feedback">
                                                                        Please provide a strong password.
                                                                    </div>
                                                                </div>
                                                            </div>
                                                        </div>
                                                        <div class="row">
                                                            <div class="col-md-6">
                                                                <div class="mb-3">
                                                                    <label class="form-label" for="validationCustom01">LGA</label>
                                                                    <select class="form-select" name="lga" placeholder="LGA">
                                                                        <option>Select LGEA</option>
                                                                        <option value="Binji">Binji</option>
                                                                        <option value="Bodinga">Bodinga</option>
                                                                        <option value="Dange-shuni">Dange Shuni</option>
                                                                        <option value="Gada">Gada</option>
                                                                        <option value="Goronyo">Goronyo</option>
                                                                        <option value="Gudu">Gudu</option>
                                                                        <option value="Gawabawa">Gawabawa</option>
                                                                        <option value="Illela">Illela</option>
                                                                        <option value="Isa">Isa</option>
                                                                        <option value="Kware">Kware</option>
                                                                        <option value="Kebbi">Kebbi</option>
                                                                        <option value="Rabah">Rabah</option>
                                                                        <option value="Sabon Birni">Sabon Birni</option>
                                                                        <option value="Shagari">Shagari</option>
                                                                        <option value="Silame">Silame</option>
                                                                        <option value="Sokoto North">Sokoto North</option>
                                                                        <option value="Sokoto South">Sokoto South</option>
                                                                        <option value="Tambuwal">Tambuwal</option>
                                                                        <option value="Tangaza">Tangaza</option>
                                                                        <option value="Tureta">Tureta</option>
                                                                        <option value="Wamako">Wamako</option>
                                                                        <option value="Wurno">Wurno</option>
                                                                        <option value="Yabo">Yabo</option>
                                                                        
                                                                    </select>
                                                                </div>
                                                            </div>
                                                            <div class="col-md-6">
                                                                <div class="mb-3">
                                                                    <label class="form-label" for="validationCustom02">Department</label>
                                                                    <select class="form-select" name="department" placeholder="Department">
                                                                        <option>Select</option>
                                                                        <option value="academic_services">Academic Services</option>
                                                                        <option value="finance_supply">Finance and Supply (F&S)</option>
                                                                        <option value="PRS">Planning Research and Statistics (PRS)</option>
                                                                        <option value="physical_planning">Physical Planning</option>
                                                                        <option value="quality_assurance">Quality Assurance</option>
                                                                        <option value="social_mobilization">Social Mobilization</option>
                                                                        <option value="teacher_development">Teacher Development</option>
                                                                    </select>
                                                                </div>
                                                            </div>
                                                        </div>
                                                        <div class="row">
                                                            <div class="col-md-6">
                                                                <div class="mb-3">
                                                                    <label class="form-label" for="validationCustom02">Designation</label>
                                                                    <input type="text" class="form-control" name="designation" id="validationCustom02" placeholder="Designation" required>
                                                                    <div class="valid-feedback">
                                                                        Please enter your Job role
                                                                    </div>
                                                                </div>
                                                            </div>
                                                            <div class="col-md-6">
                                                                <div class="mb-3">
                                                                    <label class="form-label" for="validationCustom02">Role</label>
                                                                    <select class="form-select" name="role" placeholder="Role">
                                                                        <option>Select</option>
                                                                        <option value="admin">Administrator</option>
                                                                        <option value="state">State</option>
                                                                        <option value="lga">LGA</option>
                                                                    </select>
                                                                </div>
                                                            </div>
                                                        </div>
                                                        <input type="hidden" name="register" value="true">
                                                        <button class="btn btn-success w-lg me-1" type="submit" id="submitBtn">Add User</button>
                                                        <button type="reset" class="btn btn-secondary waves-effect">Reset</button>
                                                    </form>
                                                </div>
                                            </div>
                                            <!-- End Pop up form -->
                                            
                                        </div>
                                        <!-- end row -->
                                        <div class="table-responsive mb-4">
                        <?php
                        include 'config/db_config.php';

                        // Query the database using prepared statements
                        $stmt = $conn->prepare("SELECT id, firstname, lastname, email, phone, lga, department, designation, role FROM user_role");
                        $stmt->execute();
                        $stmt->store_result();
                        $stmt->bind_result($id, $firstname, $lastname, $email, $phone, $lga, $department, $designation, $role);

                        if ($stmt->num_rows > 0) {
                            // Display table headers
                            echo "<table class='table table-centered table-nowrap mb-0'>
                            <thead>
                            <tr>
                                <th scope='col' style='width: 50px;'>
                                    <div class='form-check font-size-16'>
                                        <input type='checkbox' class='form-check-input' id='contacusercheck'>
                                        <label class='form-check-label' for='contacusercheck'></label>
                                    </div>
                                </th>";
                            echo "<th scope='col'>Name</th>
                                <th scope='col'>Email</th>
                                <th scope='col'>Phone</th>
                                <th scope='col'>Position</th>
                                <th scope='col'>Role</th>
                                <th scope='col' style='width: 200px;'>Action</th>
                            </tr>
                            </thead>
                            <tbody>";

                            while ($stmt->fetch()) {
                                echo "<tr>";
                                echo "<th scope='row'>
                                    <div class='form-check font-size-16'>
                                        <input type='checkbox' class='form-check-input' id='contacusercheck2'>
                                        <label class='form-check-label' for='contacusercheck2'></label>
                                    </div>
                                </th>";
                                echo "
                                <td>$firstname $lastname</td>
                                <td>$email</td>
                                <td>$phone</td>
                                <td>$designation</td>
                                <td>$role</td>
                                <td>
                                    <ul class='list-inline mb-0'>
                                        <li class='list-inline-item'>
                                        <a href='#updateuser-form' class='editbtn popup-form px-2 text-primary'
                                        data-id='$id' data-firstname='$firstname' data-lastname='$lastname' data-email='$email' data-phone='$phone' data-lga='$lga'
                                        data-department='$department' data-designation='$designation' data-role='$role'>
                                        <i class='uil uil-pen font-size-18'></i>
                                    </a>
                                        </li>
                                        <li class='list-inline-item'>
                                            <a href='#deleteuser-form' class='deletebtn popup-form px-2 text-danger' data-id='$id'>
                                                <i class='uil uil-trash-alt font-size-18'></i>
                                            </a>
                                        </li>
                                    </ul>
                                </td>
                            </tr>";
                            }
                            echo "</tbody></table>";
                        } else {
                            echo "No users found in the database.";
                        }
                        $stmt->close();
                        ?>
                    </div>
                </div>
            </div>
                                  
                    </div>
                    </div>
            <footer class="footer">
                <div class="container-fluid">
                    <div class="row">
                        <div class="col-sm-6">
                            <!-- Your footer content here -->
                        </div>
                        <div class="col-sm-6">
                            <div class="text-sm-end d-none d-sm-block">
                                <script>document.write(new Date().getFullYear())</script> © Sokoto State Unified School Monitoring System (SKUMONITOR).
                            </div>
                        </div>
                    </div>
                </div>
            </footer>
        </div>
   
     <!-- JAVASCRIPT -->
    <script src="assets/libs/bootstrap/js/bootstrap.bundle.min.js"></script>
    <script src="assets/libs/metismenu/metisMenu.min.js"></script>
    <script src="assets/libs/simplebar/simplebar.min.js"></script>
    <script src="assets/libs/node-waves/waves.min.js"></script>
    <script src="assets/libs/waypoints/lib/jquery.waypoints.min.js"></script>
    <script src="assets/libs/jquery.counterup/jquery.counterup.min.js"></script>

    <script src="assets/libs/magnific-popup/jquery.magnific-popup.min.js"></script>
    <script src="assets/js/pages/lightbox.init.js"></script>
    <script src="assets/js/pages/form-validation.init.js"></script>

    <script src="assets/libs/@curiosityx/bootstrap-session-timeout/index.js"></script>
    <script src="assets/js/pages/session-timeout.init.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/parsley.js/2.9.2/parsley.min.js"></script>
     <script src="assets/js/app.js"></script>

    <script>
    $(document).ready(function() {
        // Function to validate email
        function validateEmail(callback) {
            var email = $('#addUserForm #validationCustom03').val().trim();

            if (email !== '') {
                $.ajax({
                    url: 'check_email.php',
                    type: 'POST',
                    data: { email: email },
                    success: function(response) {
                        if (response === 'exists') {
                            $('#addUserForm #validationCustom03').addClass('is-invalid');
                            $('#addUserForm #validationCustom03').siblings('.invalid-feedback').text('Email already exists.');
                            callback(false);
                        } else {
                            $('#addUserForm #validationCustom03').removeClass('is-invalid');
                            callback(true);
                        }
                    }
                });
            } else {
                $('#addUserForm #validationCustom03').removeClass('is-invalid');
                callback(false);
            }
        }

        // Validate email on input in the Add User form
        $('#addUserForm #validationCustom03').on('input', function() {
            validateEmail(function(isValid) {
                // Additional logic can be implemented here if needed
            });
        });

        // Submit Add User form if validation passes
        $('#addUserForm').on('submit', function(event) {
            event.preventDefault(); // Prevent default form submission
            validateEmail(function(isValid) {
                if (isValid && this.checkValidity()) {
                    this.submit();
                }
            }.bind(this));
        });
    });

    document.addEventListener('DOMContentLoaded', function () {
        // Handle delete button click
        const deleteButtons = document.querySelectorAll('.deletebtn');
        deleteButtons.forEach(button => {
            button.addEventListener('click', function () {
                const userId = this.getAttribute('data-id');
                document.getElementById('delete-user-id').value = userId;
            });
        });

        // Handling Edit Button Click
        const editButtons = document.querySelectorAll('.editbtn');
        editButtons.forEach(button => {
            button.addEventListener('click', function () {
                const userData = {
                    id: this.getAttribute('data-id'),
                    firstname: this.getAttribute('data-firstname'),
                    lastname: this.getAttribute('data-lastname'),
                    email: this.getAttribute('data-email'),
                    phone: this.getAttribute('data-phone'),
                    lga: this.getAttribute('data-lga'),
                    department: this.getAttribute('data-department'),
                    designation: this.getAttribute('data-designation'),
                    role: this.getAttribute('data-role')
                };
                document.getElementById('edit-user-id').value = userData.id;
                document.getElementById('firstname').value = userData.firstname;
                document.getElementById('lastname').value = userData.lastname;
                document.getElementById('email').value = userData.email;
                document.getElementById('phone').value = userData.phone;
                document.getElementById('lga').value = userData.lga;
                document.getElementById('department').value = userData.department;
                document.getElementById('designation').value = userData.designation;
                document.getElementById('role').value = userData.role;
                
                let updateInput = document.querySelector('#updateuser-form [name="update"]');
                if (!updateInput) {
                    updateInput = document.createElement('input');
                    updateInput.type = 'hidden';
                    updateInput.name = 'update';
                    document.querySelector('#updateuser-form form').appendChild(updateInput);
                }
                updateInput.value = 'true';
            });
        });
    });
    </script>

    <!-- Delete confirmation popup -->
    <div class="card mfp-hide popdelete mfp-popup-form mx-auto" id="deleteuser-form">
        <div class="card-body">
            <h4 class="mb-4">Confirm User Deletion</h4>
            <form class="needs-validation" novalidate action="user.php" method="POST">
                <input type="hidden" name="delete" value="true">
                <input type="hidden" name="id" id="delete-user-id" value="<?php echo $id; ?>" > <!-- Renamed ID to avoid conflicts -->
                <p>Are you sure you want to delete this user?</p>
                <button class="btn btn-danger" type="submit">Yes, Delete it</button>
            </form>
        </div>
    </div>

    <!-- Update form -->
    <div class="card mfp-hide mfp-popup-form mx-auto" id="updateuser-form">
        <div class="card-body">
            <h4 class="mb-4">Update User details</h4>   
            <form class="needs-validation" novalidate action="user.php" method="POST">
                <input type="hidden" name="update" value="true">
                <input type="hidden" name="id" id="edit-user-id" value="<?php echo $id; ?>">
                <div class="row">
                    <div class="col-md-6">
                        <div class="mb-3">
                            <label class="form-label" for="validationCustom01">First name</label>
                            <input type="text" class="form-control" name="firstname" id="firstname" placeholder="First name" required>
                            <div class="valid-feedback">
                                Please enter your first name
                            </div>
                        </div>
                    </div>
                    <div class="col-md-6">
                        <div class="mb-3">
                            <label class="form-label" for="validationCustom02">Last name</label>
                            <input type="text" class="form-control" name="lastname" id="lastname" placeholder="Last name" required>
                            <div class="valid-feedback">
                                Please enter your last name
                            </div>
                        </div>
                    </div>
                </div>
                <div class="row">
                    <div class="col-md-4">
                        <div class="mb-3">
                            <label class="form-label" for="validationCustom03">Email</label>
                            <input type="email" class="form-control" name="email" id="email" parsley-type="email" placeholder="Email" required readonly>
                            <div class="invalid-feedback">
                                Please provide a valid email.
                            </div>
                        </div>
                    </div>
                    <div class="col-md-4">
                        <div class="mb-3">
                            <label class="form-label" for="validationCustom04">Phone number</label>
                            <input data-parsley-type="number" type="number" name="phone" class="form-control" id="phone" data-parsley-minlength="11" placeholder="Phone" required>
                            <div class="invalid-feedback">
                                Please provide a valid Phone number.
                            </div>
                        </div>
                    </div>
                    <div class="col-md-4">
                        <div class="mb-3">
                            <label class="form-label" for="validationCustom05">Password</label>
                            <input type="password" class="form-control" name="password" id="password" placeholder="Password" required readonly>
                            <div class="invalid-feedback">
                                Please provide a strong password.
                            </div>
                        </div>
                    </div>
                </div>
                <div class="row">
                    <div class="col-md-6">
                        <div class="mb-3">
                            <label class="form-label" for="validationCustom01">LGA</label>
                            <select class="form-select" name="lga" id="lga" placeholder="LGA">
                                <option>Select</option>
                                <option value="Binji">Binji</option>
                                <option value="Bodinga">Bodinga</option>
                                <option value="Dange-shuni">Dange Shuni</option>
                                <option value="Gada">Gada</option>
                                <option value="Goronyo">Goronyo</option>
                                <option value="Gudu">Gudu</option>
                                <option value="Gawabawa">Gawabawa</option>
                                <option value="Illela">Illela</option>
                                <option value="Isa">Isa</option>
                                <option value="Kware">Kware</option>
                                <option value="Kebbi">Kebbi</option>
                                <option value="Rabah">Rabah</option>
                                <option value="Sabon Birni">Sabon Birni</option>
                                <option value="Shagari">Shagari</option>
                                <option value="Silame">Silame</option>
                                <option value="Sokoto North">Sokoto North</option>
                                <option value="Sokoto South">Sokoto South</option>
                                <option value="Tambuwal">Tambuwal</option>
                                <option value="Tangaza">Tangaza</option>
                                <option value="Tureta">Tureta</option>
                                <option value="Wamako">Wamako</option>
                                <option value="Wurno">Wurno</option>
                                <option value="Yabo">Yabo</option>
                            </select>
                        </div>
                    </div>
                    <div class="col-md-6">
                        <div class="mb-3">
                            <label class="form-label" for="validationCustom02">Department</label>
                            <select class="form-select" name="department" id="department" placeholder="Department">
                                <option>Select</option>
                                <option value="academic_services">Academic Services</option>
                                <option value="finance_supply">Finance and Supply (F&S)</option>
                                <option value="PRS">Planning Research and Statistics (PRS)</option>
                                <option value="physical_planning">Physical Planning</option>
                                <option value="quality_assurance">Quality Assurance</option>
                                <option value="social_mobilization">Social Mobilization</option>
                                <option value="teacher_development">Teacher Development</option>
                            </select>
                        </div>
                    </div>
                </div>
                <div class="row">
                    <div class="col-md-6">
                        <div class="mb-3">
                            <label class="form-label" for="validationCustom02">Designation</label>
                            <input type="text" class="form-control" name="designation" id="designation" placeholder="Designation" required>
                            <div class="valid-feedback">
                                Please enter your Job role
                            </div>
                        </div>
                    </div>
                    <div class="col-md-6">
                        <div class="mb-3">
                            <label class="form-label" for="validationCustom02">Role</label>
                            <select class="form-select" name="role" id="role" placeholder="Role">
                                <option>Select</option>
                                <option value="admin">Administrator</option>
                                <option value="state">State</option>
                                <option value="lga">LGA</option>
                            </select>
                        </div>
                    </div>
                </div>
                <button class="btn btn-success w-lg me-1" type="submit">Update User</button>
                <button type="reset" class="btn btn-secondary waves-effect">Reset</button>
            </form>
        </div>
    </div>

<?php ob_end_flush(); ?>  
</body>
</html>
